Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(832)

Unified Diff: content/renderer/render_view_impl.h

Issue 18590002: Migrate MediaStream test code from content/shell/renderer/ to content/test/. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/test/layouttest_support.h ('k') | content/renderer/render_view_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/renderer/render_view_impl.h
diff --git a/content/renderer/render_view_impl.h b/content/renderer/render_view_impl.h
index 743923e060363663625f0938e8b4881202b68ecd..4813fcaaddd7855fc99c3ba4e062741adea42a03 100644
--- a/content/renderer/render_view_impl.h
+++ b/content/renderer/render_view_impl.h
@@ -93,6 +93,10 @@ class PluginInstance;
} // namespace webkit
+namespace webkit_media {
+class MediaStreamClient;
+}
+
namespace WebKit {
class WebApplicationCacheHost;
class WebApplicationCacheHostClient;
@@ -147,7 +151,6 @@ class InputTagSpeechDispatcher;
class JavaBridgeDispatcher;
class LoadProgressTracker;
class MediaStreamDispatcher;
-class MediaStreamImpl;
class MouseLockDispatcher;
class NavigationState;
class NotificationProvider;
@@ -388,6 +391,11 @@ class CONTENT_EXPORT RenderViewImpl
const gfx::Size& max_size);
void DisableAutoResizeForTesting(const gfx::Size& new_size);
+ // Overrides the MediaStreamClient used when creating MediaStream players.
+ // Must be called before any players are created.
+ void SetMediaStreamClientForTesting(
+ webkit_media::MediaStreamClient* media_stream_client);
+
// IPC::Listener implementation ----------------------------------------------
virtual bool OnMessageReceived(const IPC::Message& msg) OVERRIDE;
@@ -1097,7 +1105,8 @@ class CONTENT_EXPORT RenderViewImpl
// Check whether the preferred size has changed.
void CheckPreferredSize();
- void EnsureMediaStreamImpl();
+ // Initializes |media_stream_client_| if needed.
+ void EnsureMediaStreamClient();
// This callback is triggered when DownloadFavicon completes, either
// succesfully or with a failure. See DownloadFavicon for more
@@ -1418,8 +1427,9 @@ class CONTENT_EXPORT RenderViewImpl
// BrowserPluginManager attached to this view; lazily initialized.
scoped_refptr<BrowserPluginManager> browser_plugin_manager_;
- // MediaStreamImpl attached to this view; lazily initialized.
- MediaStreamImpl* media_stream_impl_;
+ // MediaStreamClient attached to this view; lazily initialized.
+ webkit_media::MediaStreamClient* media_stream_client_;
+ WebKit::WebUserMediaClient* web_user_media_client_;
DevToolsAgent* devtools_agent_;
« no previous file with comments | « content/public/test/layouttest_support.h ('k') | content/renderer/render_view_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698